@@ -251,7 +251,7 @@ pub enum Expr {
     },
     MapAccess {
         column: Box<Expr>,
-        key: String,
+        keys: Vec<Value>,
     },
     /// Scalar function call e.g. `LEFT(foo, 5)`
     Function(Function),
@@ -280,7 +280,17 @@ impl fmt::Display for Expr {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
             Expr::Identifier(s) => write!(f, "{}", s),
-            Expr::MapAccess { column, key } => write!(f, "{}[\"{}\"]", column, key),
+            Expr::MapAccess { column, keys } => {
+                write!(f, "{}", column)?;
+                for k in keys {
+                    match k {
+                        k @ Value::Number(_, _) => write!(f, "[{}]", k)?,
+                        Value::SingleQuotedString(s) => write!(f, "[\"{}\"]", s)?,
+                        _ => write!(f, "[{}]", k)?,
+                    }
+                }
+                Ok(())
+            }
             Expr::Wildcard => f.write_str("*"),
             Expr::QualifiedWildcard(q) => write!(f, "{}.*", display_separated(q, ".")),
             Expr::CompoundIdentifier(s) => write!(f, "{}", display_separated(s, ".")),
@@ -523,6 +533,28 @@ impl fmt::Display for AddDropSync {
     }
 }
 
+#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
+pub enum ShowCreateObject {
+    Event,
+    Function,
+    Procedure,
+    Table,
+    Trigger,
+}
+
+impl fmt::Display for ShowCreateObject {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
+        match self {
+            ShowCreateObject::Event => f.write_str("EVENT"),
+            ShowCreateObject::Function => f.write_str("FUNCTION"),
+            ShowCreateObject::Procedure => f.write_str("PROCEDURE"),
+            ShowCreateObject::Table => f.write_str("TABLE"),
+            ShowCreateObject::Trigger => f.write_str("TRIGGER"),
+        }
+    }
+}
+
 /// A top-level statement (SELECT, INSERT, CREATE, etc.)
 #[allow(clippy::large_enum_variant)]
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
@@ -685,6 +717,13 @@ pub enum Statement {
     ///
     /// Note: this is a PostgreSQL-specific statement.
     ShowVariable { variable: Vec<Ident> },
+    /// SHOW CREATE TABLE
+    ///
+    /// Note: this is a MySQL-specific statement.
+    ShowCreate {
+        obj_type: ShowCreateObject,
+        obj_name: ObjectName,
+    },
     /// SHOW COLUMNS
     ///
     /// Note: this is a MySQL-specific statement.
@@ -735,8 +774,18 @@ pub enum Statement {
         data_types: Vec<DataType>,
         statement: Box<Statement>,
     },
-    /// EXPLAIN
+    /// EXPLAIN TABLE
+    /// Note: this is a MySQL-specific statement. See <https://dev.mysql.com/doc/refman/8.0/en/explain.html>
+    ExplainTable {
+        // If true, query used the MySQL `DESCRIBE` alias for explain
+        describe_alias: bool,
+        // Table name
+        table_name: ObjectName,
+    },
+    /// EXPLAIN / DESCRIBE for select_statement
     Explain {
+        // If true, query used the MySQL `DESCRIBE` alias for explain
+        describe_alias: bool,
         /// Carry out the command and show actual run times and other statistics.
         analyze: bool,
         // Display additional information regarding the plan.
@@ -752,12 +801,29 @@ impl fmt::Display for Statement {
     #[allow(clippy::cognitive_complexity)]
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
+            Statement::ExplainTable {
+                describe_alias,
+                table_name,
+            } => {
+                if *describe_alias {
+                    write!(f, "DESCRIBE ")?;
+                } else {
+                    write!(f, "EXPLAIN ")?;
+                }
+
+                write!(f, "{}", table_name)
+            }
             Statement::Explain {
+                describe_alias,
                 verbose,
                 analyze,
                 statement,
             } => {
-                write!(f, "EXPLAIN ")?;
+                if *describe_alias {
+                    write!(f, "DESCRIBE ")?;
+                } else {
+                    write!(f, "EXPLAIN ")?;
+                }
 
                 if *analyze {
                     write!(f, "ANALYZE ")?;
@@ -1196,6 +1262,15 @@ impl fmt::Display for Statement {
                 }
                 Ok(())
             }
+            Statement::ShowCreate { obj_type, obj_name } => {
+                write!(
+                    f,
+                    "SHOW CREATE {obj_type} {obj_name}",
+                    obj_type = obj_type,
+                    obj_name = obj_name,
+                )?;
+                Ok(())
+            }
             Statement::ShowColumns {
                 extended,
                 full,
@@ -1494,7 +1569,7 @@ pub enum HiveIOFormat {
     },
 }
 
-#[derive(Debug, Clone, PartialEq, Eq, Hash)]
+#[derive(Debug, Clone, PartialEq, Eq, Hash, Default)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct HiveFormat {
     pub row_format: Option<HiveRowFormat>,
@@ -1502,16 +1577,6 @@ pub struct HiveFormat {
     pub location: Option<String>,
 }
 
-impl Default for HiveFormat {
-    fn default() -> Self {
-        HiveFormat {
-            row_format: None,
-            location: None,
-            storage: None,
-        }
-    }
-}
-
 #[derive(Debug, Clone, PartialEq, Eq, Hash)]
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 pub struct SqlOption {
