@@ -193,6 +193,7 @@ define_keywords!(
     EQUALS,
     ERROR,
     ESCAPE,
+    EVENT,
     EVERY,
     EXCEPT,
     EXEC,
@@ -493,6 +494,7 @@ define_keywords!(
     WITHOUT,
     WORK,
     WRITE,
+    XOR,
     YEAR,
     ZONE
 );
